==> sns_notification_opsgenie-1.0.0-py3-none-any.whl: package/API.md <==
# API Reference <a name="API Reference" id="api-reference"></a>

## Constructs <a name="Constructs" id="Constructs"></a>

### SnsNotifyOpsgenie <a name="SnsNotifyOpsgenie" id="sns-notification-opsgenie.SnsNotifyOpsgenie"></a>

#### Initializers <a name="Initializers" id="sns-notification-opsgenie.SnsNotifyOpsgenie.Initializer"></a>

```typescript
import { SnsNotifyOpsgenie } from 'sns-notification-opsgenie'

new SnsNotifyOpsgenie(scope: Construct, id: string)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#sns-notification-opsgenie.SnsNotifyOpsgenie.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#sns-notification-opsgenie.SnsNotifyOpsgenie.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="sns-notification-opsgenie.SnsNotifyOpsgenie.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="sns-notification-opsgenie.SnsNotifyOpsgenie.Initializer.parameter.id"></a>

- *Type:* string

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#sns-notification-opsgenie.SnsNotifyOpsgenie.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#sns-notification-opsgenie.SnsNotifyOpsgenie.getOpgsgenieTopicArn">getOpgsgenieTopicArn</a></code> | Returns an sns.Topic object that represents an SNS topic in AWS. The topic ARN is constructed based on the accountId, priority, and region parameters. |

---

##### `toString` <a name="toString" id="sns-notification-opsgenie.SnsNotifyOpsgenie.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `getOpgsgenieTopicArn` <a name="getOpgsgenieTopicArn" id="sns-notification-opsgenie.SnsNotifyOpsgenie.getOpgsgenieTopicArn"></a>

```typescript
public getOpgsgenieTopicArn(accountId: string, priority: Priority, region?: string): ITopic
```

Returns an sns.Topic object that represents an SNS topic in AWS. The topic ARN is constructed based on the accountId, priority, and region parameters.

###### `accountId`<sup>Required</sup> <a name="accountId" id="sns-notification-opsgenie.SnsNotifyOpsgenie.getOpgsgenieTopicArn.parameter.accountId"></a>

- *Type:* string

The AWS account ID where the topic is located.

---

###### `priority`<sup>Required</sup> <a name="priority" id="sns-notification-opsgenie.SnsNotifyOpsgenie.getOpgsgenieTopicArn.parameter.priority"></a>

- *Type:* <a href="#sns-notification-opsgenie.Priority">Priority</a>

The priority of the topic.

Must be one of

---

###### `region`<sup>Optional</sup> <a name="region" id="sns-notification-opsgenie.SnsNotifyOpsgenie.getOpgsgenieTopicArn.parameter.region"></a>

- *Type:* string

The AWS region where the topic is located.

If not specified, defaults to eu-west-1.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#sns-notification-opsgenie.SnsNotifyOpsgenie.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="sns-notification-opsgenie.SnsNotifyOpsgenie.isConstruct"></a>

```typescript
import { SnsNotifyOpsgenie } from 'sns-notification-opsgenie'

SnsNotifyOpsgenie.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="sns-notification-opsgenie.SnsNotifyOpsgenie.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#sns-notification-opsgenie.SnsNotifyOpsgenie.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |

---

##### `node`<sup>Required</sup> <a name="node" id="sns-notification-opsgenie.SnsNotifyOpsgenie.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---





## Enums <a name="Enums" id="Enums"></a>

### Priority <a name="Priority" id="sns-notification-opsgenie.Priority"></a>

Enumeration of priority for Alarms.

The `Priority` enum is used to represent the priority of an Alarm. It has five possible values.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#sns-notification-opsgenie.Priority.CRITICAL">CRITICAL</a></code> | indicates that the alarm is of the highest priority and requires immediate attention. |
| <code><a href="#sns-notification-opsgenie.Priority.HIGH">HIGH</a></code> | indicates that the alarm is of high priority and should be addressed as soon as possible. |
| <code><a href="#sns-notification-opsgenie.Priority.MEDIUM">MEDIUM</a></code> | indicates that the alarm is of medium priority and can be addressed in due course. |
| <code><a href="#sns-notification-opsgenie.Priority.LOW">LOW</a></code> | indicates that the alarm is of low priority and can be addressed at a later time. |
| <code><a href="#sns-notification-opsgenie.Priority.INFORMATION">INFORMATION</a></code> | indicates that the alarm is of the lowest priority and can be addressed at a later time. |

---

##### `CRITICAL` <a name="CRITICAL" id="sns-notification-opsgenie.Priority.CRITICAL"></a>

indicates that the alarm is of the highest priority and requires immediate attention.

---


##### `HIGH` <a name="HIGH" id="sns-notification-opsgenie.Priority.HIGH"></a>

indicates that the alarm is of high priority and should be addressed as soon as possible.

---


##### `MEDIUM` <a name="MEDIUM" id="sns-notification-opsgenie.Priority.MEDIUM"></a>

indicates that the alarm is of medium priority and can be addressed in due course.

---


##### `LOW` <a name="LOW" id="sns-notification-opsgenie.Priority.LOW"></a>

indicates that the alarm is of low priority and can be addressed at a later time.

---


##### `INFORMATION` <a name="INFORMATION" id="sns-notification-opsgenie.Priority.INFORMATION"></a>

indicates that the alarm is of the lowest priority and can be addressed at a later time.

---

==> sns_notification_opsgenie-1.1.0-py3-none-any.whl: package/API.md <==
# API Reference <a name="API Reference" id="api-reference"></a>

## Constructs <a name="Constructs" id="Constructs"></a>

### SnsNotifyOpsgenie <a name="SnsNotifyOpsgenie" id="sns-notification-opsgenie.SnsNotifyOpsgenie"></a>

#### Initializers <a name="Initializers" id="sns-notification-opsgenie.SnsNotifyOpsgenie.Initializer"></a>

```typescript
import { SnsNotifyOpsgenie } from 'sns-notification-opsgenie'

new SnsNotifyOpsgenie(scope: Construct, id: string, props?: ISnsNotifyOpsgenieProps)
```

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#sns-notification-opsgenie.SnsNotifyOpsgenie.Initializer.parameter.scope">scope</a></code> | <code>constructs.Construct</code> | *No description.* |
| <code><a href="#sns-notification-opsgenie.SnsNotifyOpsgenie.Initializer.parameter.id">id</a></code> | <code>string</code> | *No description.* |
| <code><a href="#sns-notification-opsgenie.SnsNotifyOpsgenie.Initializer.parameter.props">props</a></code> | <code><a href="#sns-notification-opsgenie.ISnsNotifyOpsgenieProps">ISnsNotifyOpsgenieProps</a></code> | *No description.* |

---

##### `scope`<sup>Required</sup> <a name="scope" id="sns-notification-opsgenie.SnsNotifyOpsgenie.Initializer.parameter.scope"></a>

- *Type:* constructs.Construct

---

##### `id`<sup>Required</sup> <a name="id" id="sns-notification-opsgenie.SnsNotifyOpsgenie.Initializer.parameter.id"></a>

- *Type:* string

---

##### `props`<sup>Optional</sup> <a name="props" id="sns-notification-opsgenie.SnsNotifyOpsgenie.Initializer.parameter.props"></a>

- *Type:* <a href="#sns-notification-opsgenie.ISnsNotifyOpsgenieProps">ISnsNotifyOpsgenieProps</a>

---

#### Methods <a name="Methods" id="Methods"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#sns-notification-opsgenie.SnsNotifyOpsgenie.toString">toString</a></code> | Returns a string representation of this construct. |
| <code><a href="#sns-notification-opsgenie.SnsNotifyOpsgenie.getOpgsgenieTopicArn">getOpgsgenieTopicArn</a></code> | Returns an sns.Topic object that represents an SNS topic in AWS. The topic ARN is constructed based on the accountId, priority, and region parameters. |

---

##### `toString` <a name="toString" id="sns-notification-opsgenie.SnsNotifyOpsgenie.toString"></a>

```typescript
public toString(): string
```

Returns a string representation of this construct.

##### `getOpgsgenieTopicArn` <a name="getOpgsgenieTopicArn" id="sns-notification-opsgenie.SnsNotifyOpsgenie.getOpgsgenieTopicArn"></a>

```typescript
public getOpgsgenieTopicArn(accountId: string, priority: Priority, region?: string): ITopic
```

Returns an sns.Topic object that represents an SNS topic in AWS. The topic ARN is constructed based on the accountId, priority, and region parameters.

###### `accountId`<sup>Required</sup> <a name="accountId" id="sns-notification-opsgenie.SnsNotifyOpsgenie.getOpgsgenieTopicArn.parameter.accountId"></a>

- *Type:* string

The AWS account ID where the topic is located.

---

###### `priority`<sup>Required</sup> <a name="priority" id="sns-notification-opsgenie.SnsNotifyOpsgenie.getOpgsgenieTopicArn.parameter.priority"></a>

- *Type:* <a href="#sns-notification-opsgenie.Priority">Priority</a>

The priority of the topic.

Must be one of

---

###### `region`<sup>Optional</sup> <a name="region" id="sns-notification-opsgenie.SnsNotifyOpsgenie.getOpgsgenieTopicArn.parameter.region"></a>

- *Type:* string

The AWS region where the topic is located.

If not specified, defaults to eu-west-1.

---

#### Static Functions <a name="Static Functions" id="Static Functions"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#sns-notification-opsgenie.SnsNotifyOpsgenie.isConstruct">isConstruct</a></code> | Checks if `x` is a construct. |

---

##### ~~`isConstruct`~~ <a name="isConstruct" id="sns-notification-opsgenie.SnsNotifyOpsgenie.isConstruct"></a>

```typescript
import { SnsNotifyOpsgenie } from 'sns-notification-opsgenie'

SnsNotifyOpsgenie.isConstruct(x: any)
```

Checks if `x` is a construct.

###### `x`<sup>Required</sup> <a name="x" id="sns-notification-opsgenie.SnsNotifyOpsgenie.isConstruct.parameter.x"></a>

- *Type:* any

Any object.

---

#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#sns-notification-opsgenie.SnsNotifyOpsgenie.property.node">node</a></code> | <code>constructs.Node</code> | The tree node. |

---

##### `node`<sup>Required</sup> <a name="node" id="sns-notification-opsgenie.SnsNotifyOpsgenie.property.node"></a>

```typescript
public readonly node: Node;
```

- *Type:* constructs.Node

The tree node.

---




## Protocols <a name="Protocols" id="Protocols"></a>

### ISnsNotifyOpsgenieProps <a name="ISnsNotifyOpsgenieProps" id="sns-notification-opsgenie.ISnsNotifyOpsgenieProps"></a>

- *Implemented By:* <a href="#sns-notification-opsgenie.ISnsNotifyOpsgenieProps">ISnsNotifyOpsgenieProps</a>


#### Properties <a name="Properties" id="Properties"></a>

| **Name** | **Type** | **Description** |
| --- | --- | --- |
| <code><a href="#sns-notification-opsgenie.ISnsNotifyOpsgenieProps.property.qualifier">qualifier</a></code> | <code>string</code> | *No description.* |

---

##### `qualifier`<sup>Optional</sup> <a name="qualifier" id="sns-notification-opsgenie.ISnsNotifyOpsgenieProps.property.qualifier"></a>

```typescript
public readonly qualifier: string;
```

- *Type:* string

---

## Enums <a name="Enums" id="Enums"></a>

### Priority <a name="Priority" id="sns-notification-opsgenie.Priority"></a>

Enumeration of priority for Alarms.

The `Priority` enum is used to represent the priority of an Alarm. It has five possible values.

#### Members <a name="Members" id="Members"></a>

| **Name** | **Description** |
| --- | --- |
| <code><a href="#sns-notification-opsgenie.Priority.CRITICAL">CRITICAL</a></code> | indicates that the alarm is of the highest priority and requires immediate attention. |
| <code><a href="#sns-notification-opsgenie.Priority.HIGH">HIGH</a></code> | indicates that the alarm is of high priority and should be addressed as soon as possible. |
| <code><a href="#sns-notification-opsgenie.Priority.MEDIUM">MEDIUM</a></code> | indicates that the alarm is of medium priority and can be addressed in due course. |
| <code><a href="#sns-notification-opsgenie.Priority.LOW">LOW</a></code> | indicates that the alarm is of low priority and can be addressed at a later time. |
| <code><a href="#sns-notification-opsgenie.Priority.INFORMATION">INFORMATION</a></code> | indicates that the alarm is of the lowest priority and can be addressed at a later time. |

---

##### `CRITICAL` <a name="CRITICAL" id="sns-notification-opsgenie.Priority.CRITICAL"></a>

indicates that the alarm is of the highest priority and requires immediate attention.

---


##### `HIGH` <a name="HIGH" id="sns-notification-opsgenie.Priority.HIGH"></a>

indicates that the alarm is of high priority and should be addressed as soon as possible.

---


##### `MEDIUM` <a name="MEDIUM" id="sns-notification-opsgenie.Priority.MEDIUM"></a>

indicates that the alarm is of medium priority and can be addressed in due course.

---


##### `LOW` <a name="LOW" id="sns-notification-opsgenie.Priority.LOW"></a>

indicates that the alarm is of low priority and can be addressed at a later time.

---


##### `INFORMATION` <a name="INFORMATION" id="sns-notification-opsgenie.Priority.INFORMATION"></a>

indicates that the alarm is of the lowest priority and can be addressed at a later time.

---
